Get the extension of a file
get_file_extension.RdInternally used in rename_files_with_number() for ex.
Warning: don't work when there is '.' in the name of the file before the extension
get_file_extension.RdInternally used in rename_files_with_number() for ex.
Warning: don't work when there is '.' in the name of the file before the extension